textgrad.optimizer.optimizer
============================

.. automodule:: textgrad.optimizer.optimizer

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Optimizer
      TextualGradientDescent
      TextualGradientDescentwithMomentum
   
   

   
   
   



